import { createSignal, For, Show } from "solid-js";
import { cache, createAsync, A, type RouteDefinition } from "@solidjs/router";

const getNewsList = cache(async () => {
  "use server";
  return await fetch("https://content.dd-ix.net/news/en").then((data) =>
    data.json()
  );
}, "news-list");

const getNewsTags = cache(async () => {
  "use server";
  return await fetch("https://content.dd-ix.net/news/keywords").then((data) =>
    data.json()
  );
}, "news-tags");

export const route = {
  load: () => {
    getNewsList();
    getNewsTags();
  },
} satisfies RouteDefinition;

export const NewsList = ({ limit }: { limit: number }) => {
  const newsList = createAsync(() => getNewsList());
  const tags = createAsync(() => getNewsTags());

  return (
    <For each={newsList()?.slice(0, limit)}>
      {(post) => (
        <A href={`/news/${post.slug}`}>
          <figure class="card md:card-side bg-base-100 shadow-xl mt-4">
            <img
              src={`https://content.dd-ix.net/news/assets/${post.image}`}
              alt={post.title}
              class="md:w-48 object-cover"
            />
            <div class="card-body">
              <h2 class="card-title">{post.title}</h2>
              <p>{post.published}</p>
              <p>{post.description}</p>
            </div>
          </figure>
        </A>
      )}
    </For>
  );
};
