import { createSignal, For, Show } from "solid-js";
import { cache, createAsync, A, type RouteDefinition } from "@solidjs/router";
import { clientOnly } from "@solidjs/start";
const TrafficChart = clientOnly(() => import("~/components/TrafficChart"));
const DNSChart = clientOnly(() => import("~/components/DNSChart"));

const getTraffic = cache(async () => {
  "use server";
  return await fetch("https://content.dd-ix.net/stats/traffic").then((data) =>
    data.json()
  );
}, "stats-traffic");

const getQueries = cache(async () => {
  "use server";
  return await fetch("https://content.dd-ix.net/stats/as112").then((data) =>
    data.json()
  );
}, "stats-queries");

export const route = {
  load: () => {
    getTraffic();
    getQueries();
  },
} satisfies RouteDefinition;

export default () => {
  const traffic = createAsync(() => getTraffic());
  const queries = createAsync(() => getQueries());

  return (
    <section class="container mx-auto p-4">
      <h1 class="mb-12 mt-40">Statistics</h1>
      <h2>Traffic</h2>
      <div role="tablist" class="tabs tabs-lifted">
        <input
          type="radio"
          name="my_tabs_2"
          role="tab"
          class="tab"
          aria-label="Two&nbsp;days"
          checked
        />
        <div
          role="tabpanel"
          class="tab-content bg-base-100 border-base-300 rounded-box p-6"
        >
          <TrafficChart
            data={traffic()?.two_days}
            fallback={<div>Loading</div>}
          />
        </div>

        <input
          type="radio"
          name="my_tabs_2"
          role="tab"
          class="tab"
          aria-label="Week"
        />
        <div
          role="tabpanel"
          class="tab-content bg-base-100 border-base-300 rounded-box p-6"
        >
          <TrafficChart
            data={traffic()?.seven_days}
            fallback={<div>Loading</div>}
          />
        </div>

        <input
          type="radio"
          name="my_tabs_2"
          role="tab"
          class="tab"
          aria-label="Month"
        />
        <div
          role="tabpanel"
          class="tab-content bg-base-100 border-base-300 rounded-box p-6"
        >
          <TrafficChart
            data={traffic()?.month}
            fallback={<div>Loading</div>}
          />
        </div>
      </div>

      <h2>DNS Queries</h2>
      <div role="tablist" class="tabs tabs-lifted">
        <input
          type="radio"
          name="my_tabs_3"
          role="tab"
          class="tab"
          aria-label="Two&nbsp;days"
          checked
        />
        <div
          role="tabpanel"
          class="tab-content bg-base-100 border-base-300 rounded-box p-6"
        >
          <DNSChart
            data={queries()?.two_days}
            fallback={<div>Loading</div>}
          />
        </div>

        <input
          type="radio"
          name="my_tabs_3"
          role="tab"
          class="tab"
          aria-label="Week"
        />
        <div
          role="tabpanel"
          class="tab-content bg-base-100 border-base-300 rounded-box p-6"
        >
          <DNSChart
            data={queries()?.seven_days}
            fallback={<div>Loading</div>}
          />
        </div>

        <input
          type="radio"
          name="my_tabs_3"
          role="tab"
          class="tab"
          aria-label="Month"
        />
        <div
          role="tabpanel"
          class="tab-content bg-base-100 border-base-300 rounded-box p-6"
        >
          <DNSChart
            data={queries()?.month}
            fallback={<div>Loading</div>}
          />
        </div>
      </div>
    </section>
  );
};
